@@ -47,8 +47,7 @@ For read handles:
     $r->seek(2,SEEK_CUR); # returns 1, discards skipped bytes
     $r->seek(-1,SEEK_CUR); # returns 0, can't seek back
     
-    # not yet supported, throws exception:
-    # $r->poll_cb(sub { .... });
+    $r->poll_cb(sub { .... });
 
 For write handles:
 
@@ -163,6 +162,8 @@ The file handle should be a regular file opened for reading. The response
 should have a Content-Length header set to the file size. After calling
 sendfile(), call C<close()> on the writer.
 
+B<Note:> Not supported for HTTP/2 responses. Use C<write()> instead.
+
     my $w = $req->start_streaming(200, [
         'Content-Type' => 'application/octet-stream',
         'Content-Length' => -s $filename,
