@@ -7,8 +7,10 @@ use Scalar::Util qw/weaken/;
 
 sub assign_request_handler {
     my $self = shift;
-    weaken $self;
     $self->{endjinn}->psgi_request_handler(shift);
+    # Weaken BEFORE creating closure to prevent circular reference
+    # (object -> _term -> closure -> $self -> object)
+    weaken $self;
     # Plack::Loader::Restarter will SIGTERM the parent
     $self->{_term} = EV::signal 'TERM', sub { $self && $self->quit };
     return;
@@ -60,6 +62,14 @@ Watcher priority options C<--read-priority>, C<--write-priority>, and
 C<--accept-priority> can be used to set libev I/O watcher priorities.
 Valid range is -2 (lowest) to +2 (highest), default is 0.
 
+TLS, HTTP/2, and PROXY protocol can be configured via C<-o> server options:
+
+    plackup -s Feersum \
+      -o tls_cert_file=server.crt -o tls_key_file=server.key \
+      -o h2=1 -o proxy_protocol=1 app.psgi
+
+See L<Feersum::Runner> for full documentation of these options.
+
 =head1 METHODS
 
 =over 4
